# Welcome
The Axway Client SDK Generator produces code based on a Swagger JSON file. The generated code contains the data models,
authentication helpers, API methods etc. Below you will find the instructions on how to integrate the generated code
into your project.

## Module Dependency Configuration

You must install the [ti.superagent](https://github.com/appcelerator-modules/ti.superagent/releases) and [ti.oauth](https://github.com/appcelerator-modules/ti.oauth) Titanium modules.

1. Installation via Appcelerator Studio

    * Go to Help > Install Mobile Module...
    * You can provide the module url or a zip file

2. Manual Installation

    * Download the module
    * Unzip the module
    * Copy the module to `/User/<username>/Library/Application Support/Titanium/modules` or into your local project

## Installation

The generated zip file contains the following:

1. This `README.md` file.
2. A `studentcar` directory containing the source-code.

## Steps to integrate the generated code into your project

1. Create a __Titanium Alloy project (Default Alloy Project)__.
2. Under the `app` directory create a new `lib` directoy.
3. Copy the generated directory `studentcar` to the created `lib` directory.
4. Add the below code in `alloy.js`.

Initialize the SDK & Client

```javascript
var sdk = require('./studentcar');
var SDKClient = new sdk.Client();
```
Now based on the API's authentication type copy the required code to the alloy.js file.

 For OAuth, setup client id & client secret

```javascript
// Set the client-id
SDKClient.authentications.set('client_id', 'CLIENT_ID');
// Set the client-secret
SDKClient.authentications.set('client_secret', 'CLIENT_SECRET');
```
Optional: If you are using OAuth Password (`Resource Owner Password Credentials Grant`), set the username and password as shown in the code below.

```javascript
SDKClient.authentications.set('username', 'YOUR_OAUTH_USERNAME');
SDKClient.authentications.set('password', 'YOUR_OAUTH_PASSWORD');
```
Initializing OAuth

```javascript
var OAuth = new sdk.OAuth();
```

When testing against test servers, you might need to bypass the validation of their certificate.

```javascript
OAuth.ignoreSslError = true;
```

Create a global instance of OAuth and client

```javascript
Alloy.Globals.OAuth = OAuth;
Alloy.Globals.SDKClient = SDKClient;
```

## Usage

Once you are done with the setup, you can use following code snippet to perform OAuth login. Authentication via HTTP Basic
and API KEY is automatic. *If the API supports multiple Authentications, use any one of the below based on your requirement.*

### OAuth


For OAuth Implicit login:
```javascript
Alloy.Globals.OAuth.authorizeImplicitly(function(err, data) {
   alert(data); // "data" will contain the access token, refresh token etc.
});
```


__NOTE__: The tokens are stored internally and used when we make the API calls.

To logout from OAuth:

```javascript
Alloy.Globals.OAuth.logout(function(data) {
   console.log(data);
});
```

### API Calls

The results object from the API call could be an array or a single object.

```javascript
<API Global Object>.findPetsByStatus(['Available'], {}, function(err, results, clientObject) {
   alert(results);
});
```

The __`alloy.js`__ file would finally look like below

```javascript

var sdk = require('./petstore');
var SDKClient = new sdk.Client();

// API Key
SDKClient.authentications['API Key'].apiKey = 'API_KEY';

// Http Basic
SDKClient.authentications['HTTP Basic'].username = 'YOUR_USERNAME';
SDKClient.authentications['HTTP Basic'].password = 'YOUR_PASSWORD';

// Set the client-id
SDKClient.authentications.set('client_id', 'CLIENT_ID');

// Set the client-secret
SDKClient.authentications.set('client_secret', 'CLIENT_SECRET');

// Setup username and password if you are using oauth password
SDKClient.authentications.set('username', 'YOUR_OAUTH_USERNAME');
SDKClient.authentications.set('password', 'YOUR_OAUTH_PASSWORD');

// Initializing OAuth
var OAuth = new sdk.OAuth();

// For self sign certificate
OAuth.ignoreSslError = true;

// Make global instance
Alloy.Globals.OAuth = OAuth;
Alloy.Globals.API = new sdk.DefaultAPI(client);
Alloy.Globals.SDKClient = SDKClient;
```

The __`index.js`__ file would look like this:
```xml
<Alloy>
	<Window>
		<Button onClick="authorize">Authorize</Button>
	</Window>
</Alloy>
```

The __`index.js`__ file would look like this:

```js
function authorize() {
	Alloy.Globals.OAuth.authorizeImplicitly(function(err, data) {
	   if (err != null) {
	       console.log(data);
	       alert(data);

	       Alloy.Globals.API.findPetsByStatus(['Available'], {}, function(err, results, cli) {
	           alert(results);
	       });

	       Alloy.Globals.OAuth.logout(function(ldata) {
	           console.log(ldata);
	       });
	   } else {
	       console.log("An error occurred: " + error);
	   }
	});
}

$.index.open();
```

## Troubleshooting

- For the iOS simulator: If the callback url doesn't launch the application and shows the error `The requested URL/callback was not found in the server`. This could be because there is a server running on port 80 on the system.
 To male the callback work, you will need to restart the server. If it uses Apache, use the below command:

```bash
sudo /usr/sbin/apachectl stop
```
