// /api/DefaultAPI.js
 

var Client = require('../client'),
	student = require('../model/student'),
	testuser = require('../model/testuser'),
	car = require('../model/car');

var DefaultAPI = function DefaultAPI(client) {
	this.client = client || Client.default;

	var self = this;

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestuserCount = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = integer;

		return this.client.callApi(
			'/testuser/count', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findCarCount = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = integer;

		return this.client.callApi(
			'/car/count', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The find succeeded, and the results are available.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findStudentByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling findStudentByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = student;

		return this.client.callApi(
			'/student/{id}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The student ID
	 * @param {Object} options['Update'] Update body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateStudentByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Update'];

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling updateStudentByID';
		}

		var pathParams = {
			'id': id,
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student/{id}', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The student ID
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteStudentByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling deleteStudentByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student/{id}', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {Object} options['Find and Modify'] Find and Modify body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateStudentFindAndModify = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Find and Modify'];


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page'],
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student/findAndModify', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {Object} options['Find and Modify'] Find and Modify body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateTestuserFindAndModify = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Find and Modify'];


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page'],
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser/findAndModify', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The find succeeded, and the results are available.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestuserByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling findTestuserByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = testuser;

		return this.client.callApi(
			'/testuser/{id}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The testuser ID
	 * @param {Object} options['Update'] Update body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateTestuserByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Update'];

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling updateTestuserByID';
		}

		var pathParams = {
			'id': id,
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser/{id}', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The testuser ID
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteTestuserByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling deleteTestuserByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser/{id}', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The find succeeded, and the results are available.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findCarByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling findCarByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = car;

		return this.client.callApi(
			'/car/{id}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The car ID
	 * @param {Object} options['Update'] Update body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateCarByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Update'];

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling updateCarByID';
		}

		var pathParams = {
			'id': id,
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car/{id}', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id The car ID
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteCarByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling deleteCarByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car/{id}', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestuser = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [testuser];

		return this.client.callApi(
			'/testuser', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Create'] Create body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createTestuser = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Create'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteTestuser = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {String} field The field name that must be distinct.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findStudentDistinctByFIELD = function(field, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'field' is set
		if (field === null) {
			throw 'Missing the required parameter \'field\' when calling findStudentDistinctByFIELD';
		}

		var pathParams = {
			'field': field,
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = ['String'];

		return this.client.callApi(
			'/student/distinct/{field}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {String} id the test user id
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestapiByID = function(id, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'id' is set
		if (id === null) {
			throw 'Missing the required parameter \'id\' when calling findTestapiByID';
		}

		var pathParams = {
			'id': id
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testapi/{id}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {String} field The field name that must be distinct.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestuserDistinctByFIELD = function(field, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'field' is set
		if (field === null) {
			throw 'Missing the required parameter \'field\' when calling findTestuserDistinctByFIELD';
		}

		var pathParams = {
			'field': field,
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = ['String'];

		return this.client.callApi(
			'/testuser/distinct/{field}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findTestuserQuery = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [testuser];

		return this.client.callApi(
			'/testuser/query', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findCar = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [car];

		return this.client.callApi(
			'/car', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Create'] Create body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createCar = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Create'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteCar = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findCarQuery = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [car];

		return this.client.callApi(
			'/car/query', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {String} field The field name that must be distinct.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findCarDistinctByFIELD = function(field, options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;

		// verify the required parameter 'field' is set
		if (field === null) {
			throw 'Missing the required parameter \'field\' when calling findCarDistinctByFIELD';
		}

		var pathParams = {
			'field': field,
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = ['String'];

		return this.client.callApi(
			'/car/distinct/{field}', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Upsert'] Upsert body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createTestuserUpsert = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Upsert'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/testuser/upsert', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Upsert'] Upsert body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createStudentUpsert = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Upsert'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student/upsert', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findStudent = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [student];

		return this.client.callApi(
			'/student', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Create'] Create body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createStudent = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Create'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.deleteStudent = function(callback) {
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/student', 'delete',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {Object} options['Upsert'] Upsert body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.createCarUpsert = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Upsert'];


		var pathParams = {
		};
		var queryParams = {
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car/upsert', 'post',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findStudentQuery = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = [student];

		return this.client.callApi(
			'/student/query', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.findStudentCount = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = null;


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page']
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = integer;

		return this.client.callApi(
			'/student/count', 'get',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};

	/**
	 * 
	 * 
	 * @param {number} options['limit'] The number of records to fetch. The value must be greater than 0, and no greater than 1000.
	 * @param {number} options['skip'] The number of records to skip. The value must not be less than 0.
	 * @param {String} options['where'] Constrains values for fields. The value should be encoded JSON.
	 * @param {String} options['order'] A dictionary of one or more fields specifying sorting of results. In general, you can sort based on any predefined field that you can query using the where operator, as well as on custom fields. The value should be encoded JSON.
	 * @param {String} options['sel'] Selects which fields to return from the query. Others are excluded. The value should be encoded JSON.
	 * @param {String} options['unsel'] Selects which fields to not return from the query. Others are included. The value should be encoded JSON.
	 * @param {number} options['page'] Request page number starting from 1.
	 * @param {number} options['per_page'] Number of results per page.
	 * @param {Object} options['Find and Modify'] Find and Modify body
	 * @param {function} callback the callback function, accepting three arguments: error, data, response
	 */
	self.updateCarFindAndModify = function(options, callback) {
		if ('function' === typeof options) {
			callback = options;
			options = {};
		}
		var postBody = options['Find and Modify'];


		var pathParams = {
		};
		var queryParams = {
			'limit': options['limit'],
			'skip': options['skip'],
			'where': options['where'],
			'order': options['order'],
			'sel': options['sel'],
			'unsel': options['unsel'],
			'page': options['page'],
			'per_page': options['per_page'],
		};
		var headerParams = {
		};
		var formParams = {
		};

		var authNames = ['OAuthImplicit'];
		var contentTypes = ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'];
		var accepts = ['application/json', 'application/xml', 'text/yaml', 'text/csv', 'text/plain'];
		var returnType = null;

		return this.client.callApi(
			'/car/findAndModify', 'put',
			pathParams, queryParams, headerParams, formParams, postBody,
			authNames, contentTypes, accepts, returnType, callback
		);
	};
};

module.exports = DefaultAPI;
