 

var oauth = require('ti.oauth');

var OAuth = function OAuth() {
    var self = this;

    // Setting up default https to false
    this.ignoreSslError = false; 


    // Login method for OAuth Implicit
    self.authorizeImplicitly = function(callback) {
        // Setting ignoreSslError value
        oauth.default.ignoreSslError =  this.ignoreSslError;
        var securityDef = Alloy.Globals.SDKClient.authentications['OAuthImplicit'];
        this.implicitly(securityDef, function(err, data) {
            // Setting up details
            setAuthDetails(err, data, 'OAuthImplicit', function(error, result) {
                callback(error, result);
            });
        });
    };


    // Logout method for all OAuth types
    self.logout = function(callback) { 
        setTokenNull('OAuthImplicit');
        callback('Successfully logged out.');
    };

};


// Method to validate params and request for (OAuth Implicit) access_token
OAuth.prototype.implicitly = function(securityDef, callback) {
    // Assigning client_id
    securityDef.client_id = Alloy.Globals.SDKClient.authentications.client_id;
    var requiredParams = [
        'authorizationUrl',
        'client_id',
        'scopes'
    ];
    // Validating params
    validateParameters(requiredParams, securityDef, function(error) {
        if (error) return callback(error);
        // Requesting for Implicit access_token
        oauth.default.authorizeImplicitly(securityDef.authorizationUrl, securityDef.client_id, securityDef.scopes, function (err, implicit) {
            callback(err, implicit);
        });
    });
}; 


// Function to validate params
function validateParameters(requiredParams, securityDef, callback) {
    var missingParams = [],
        msg = null;

    for (var i in requiredParams) {
        if(securityDef[requiredParams[i]] === undefined) {
            missingParams.push(requiredParams[i]);
        }
    }
    if (missingParams.length > 0) {
        msg = 'Missing one or more parameters: ' + missingParams.join(', ');
    }
    callback(msg);
};


// Function to set auth details
function setAuthDetails(err, data, authType, callback) {
    if (!err && data) {
        if (data.accessToken) Alloy.Globals.SDKClient.authentications[authType].accessToken =  data.accessToken;
        if (data.refreshToken) Alloy.Globals.SDKClient.authentications[authType].refreshToken =  data.refreshToken;
        if (data.expiresIn) Alloy.Globals.SDKClient.authentications[authType].expiresIn =  data.expiresIn;
        if (data.tokenType) Alloy.Globals.SDKClient.authentications[authType].tokenType = data.tokenType;
    }
    callback(err, data);
}

// Function to set auth details to null
function setTokenNull(authType) {
    Alloy.Globals.SDKClient.authentications[authType].accessToken = null;
    Alloy.Globals.SDKClient.authentications[authType].refreshToken = null;
    Alloy.Globals.SDKClient.authentications[authType].expiresIn = null;
    Alloy.Globals.SDKClient.authentications[authType].tokenType = null;
}


module.exports = OAuth;

